=====
Usage
=====

To use motionSensor.py in a project::

    from omlaxtcp import motionSensor
    
To use tempSensor.py in a project::

    from omlaxtcp import tempSensor

To use TCP.py in a project::

    from omlaxtcp import TCP
